mask_backup_config

Function mask_backup_config 

pub fn mask_backup_config(config: Value) -> (Value, bool)
Mask the secret values in a config blob, returning the masked blob and whether any secret was set.