pub async fn test_destination(
state: &AppState,
dest: &BackupDestination,
) -> BackupTestResultExpand description
Probe a destination: writability for local, a short rclone connectivity check for remotes.
pub async fn test_destination(
state: &AppState,
dest: &BackupDestination,
) -> BackupTestResultProbe a destination: writability for local, a short rclone connectivity check for remotes.