pub async fn render(pool: &SqlitePool, cfg: &Config) -> Result<String>Expand description
Render the full metrics page in Prometheus text exposition format.
pub async fn render(pool: &SqlitePool, cfg: &Config) -> Result<String>Render the full metrics page in Prometheus text exposition format.