pub struct MirrorRecorderManager { /* private fields */ }Expand description
Owns and supervises the per-camera mirror recorder tasks.
Implementations
Sourceimpl MirrorRecorderManager
impl MirrorRecorderManager
pub fn new( pool: SqlitePool, cfg: Arc<Config>, mirror_root: PathBuf, ) -> Arc<Self>
Sourcepub async fn start_all(self: &Arc<Self>) -> Result<()>
pub async fn start_all(self: &Arc<Self>) -> Result<()>
Start mirror recorders for every camera that should mirror.
Sourcepub async fn reconcile(self: &Arc<Self>, camera_id: &str)
pub async fn reconcile(self: &Arc<Self>, camera_id: &str)
Reconcile a single camera’s mirror recorder against its current DB state (stop, then restart
when it should mirror). Mirroring is continuous and independent of the recording schedule, so
this only depends on should_record() + mirror_enabled.