pub async fn get_i64(pool: &SqlitePool, key: &str) -> Option<i64>Expand description
Read an integer setting, or None if unset / unparseable.
pub async fn get_i64(pool: &SqlitePool, key: &str) -> Option<i64>Read an integer setting, or None if unset / unparseable.