pub async fn storage_report(
pool: &SqlitePool,
cfg: &Config,
) -> Result<StorageReport>Expand description
Compute a storage report combining disk stats with the recordings footprint and write rate.
pub async fn storage_report(
pool: &SqlitePool,
cfg: &Config,
) -> Result<StorageReport>Compute a storage report combining disk stats with the recordings footprint and write rate.